cmoncrawl.common.types.DomainRecord — CmonCrawl 1.0.0 documentation

Toggle navigation sidebar
Toggle in-page Table of Contents

# cmoncrawl.common.types.DomainRecord

class cmoncrawl.common.types.DomainRecord(filename: str, url: str | None, offset: int, length: int, digest: str | None = None, encoding: str | None = None, timestamp: datetime.datetime | None = None)
  __init__(filename: str, url: str | None, offset: int, length: int, digest: Optional[str] = None, encoding: Optional[str] = None, timestamp: Optional[datetime] = None) → None

  Methods

  `__init__`(filename, url, offset, length[, ...]) |
  `from_dict`(kvs, *[, infer_missing]) |
  `from_json`(s, *[, parse_float, parse_int, ...]) |
  `schema`(*[, infer_missing, only, exclude, ...]) |
  `to_dict`([encode_json]) |
  `to_json`(*[, skipkeys, ensure_ascii, ...]) |

  Attributes

  `digest` |
  `encoding` |
  `timestamp` |
  `filename` |
  `url` |
  `offset` |
  `length` |